#[non_exhaustive]pub enum QuicEvent {
Message(Vec<u8>),
KeyChange(KeyChange),
}Expand description
QUIC events that should be handled by the caller.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Message(Vec<u8>)
These bytes should be handled as an unencrypted TLS handshake message.
KeyChange(KeyChange)
The key material should be changed.