Accepted

Struct Accepted 

pub struct Accepted { /* private fields */ }
Represents that a ClientHello message has been received.

The handshake can be progressed by choosing a ServerConfig based on Accepted::client_hello() and providing it to Accepted::choose_config().

Implementations

Source

impl Accepted

pub fn client_hello(&self) -> ClientHello<'_>

Get the ClientHello for this connection.

pub fn choose_config( self, config: Arc<ServerConfig>, params: Vec<u8>, output: &mut Vec<QuicEvent>, ) -> Result<ServerHandshake, Error>

Choose a ServerConfig to progress the handshake.

Resolves an Accepted, providing the ServerConfig that should be used for the session, and the TLS-encoded QUIC transport parameters to send.

Returns an error if configuration-dependent validation of the received ClientHello message fails.

Events are appended to output.