ClientConnection

Struct ClientConnection 

pub struct ClientConnection { /* private fields */ }
A QUIC client connection.

Implementations

Source

impl ClientConnection

pub fn new( config: Arc<ClientConfig>, quic_version: Version, name: ServerName<'static>, params: Vec<u8>, ) -> Result<Self, Error>

Make a new QUIC ClientConnection.

This differs from ClientConnection::new() in that it takes an extra params argument, which contains the TLS-encoded transport parameters to send.

pub fn new_with_alpn( config: Arc<ClientConfig>, quic_version: Version, name: ServerName<'static>, params: Vec<u8>, alpn_protocols: Vec<ApplicationProtocol<'static>>, ) -> Result<Self, Error>

Make a new QUIC ClientConnection with custom ALPN protocols.

pub fn is_early_data_accepted(&self) -> bool

Returns True if the server signalled it will process early data.

If you sent early data and this returns false at the end of the handshake then the server will not process the data. This is not an error, but you may wish to resend the data.

pub fn tls13_tickets_received(&self) -> u32

Returns the number of TLS1.3 tickets that have been received.

pub fn exporter(&mut self) -> Result<KeyingMaterialExporter, Error>

Returns an object that can derive key material from the agreed connection secrets.

See RFC5705 for more details on what this is for.

This function can be called at most once per connection.

This function will error:

  • if called prior to the handshake completing; (check with CommonState::is_handshaking first).
  • if called more than once per connection.

Methods from Deref<Target = ConnectionOutputs>

pub fn peer_identity(&self) -> Option<&Identity<'static>>

Retrieves the certificate chain or the raw public key used by the peer to authenticate.

This is made available for both full and resumed handshakes.

For clients, this is the identity of the server. For servers, this is the identity of the client, if client authentication was completed.

The return value is None until this value is available.

pub fn alpn_protocol(&self) -> Option<&ApplicationProtocol<'static>>

Retrieves the protocol agreed with the peer via ALPN.

A return value of None after handshake completion means no protocol was agreed (because no protocols were offered or accepted by the peer).

pub fn negotiated_cipher_suite(&self) -> Option<SupportedCipherSuite>

Retrieves the cipher suite agreed with the peer.

This returns None until the cipher suite is agreed.

pub fn negotiated_key_exchange_group( &self, ) -> Option<&'static dyn SupportedKxGroup>

Retrieves the key exchange group agreed with the peer.

This function may return None depending on the state of the connection, the type of handshake, and the protocol version.

If CommonState::is_handshaking() is true this function will return None. Similarly, if the ConnectionOutputs::handshake_kind() is HandshakeKind::Resumed and the ConnectionOutputs::protocol_version() is TLS 1.2, then no key exchange will have occurred and this function will return None.

pub fn protocol_version(&self) -> Option<ProtocolVersion>

Retrieves the protocol version agreed with the peer.

This returns None until the version is agreed.

pub fn handshake_kind(&self) -> Option<HandshakeKind>

Which kind of handshake was performed.

This tells you whether the handshake was a resumption or not.

This will return None before it is known which sort of handshake occurred.