NeedsInput

Struct NeedsInput 

pub struct NeedsInput { /* private fields */ }
More data needs to be received to make progress.

Provide the data to Self::process().

Implementations

Source

impl NeedsInput

pub fn process( self, input: &mut dyn TlsInputBuffer, output: &mut Vec<QuicEvent>, ) -> Result<ServerHandshake, Error>

Progress the handshake by receiving further unencrypted TLS handshake data.

The input should be ordered QUIC CRYPTO stream data for one encryption level.

Handshake data obtained from separate encryption levels should be supplied in separate calls.

How much of the input buffer is consumed is recorded by a call to TlsInputBuffer::discard(). Unconsumed data should be presented again on the next call.

An error from this function is fatal to the connection, as it consumes the NeedsInput object.

On success, this returns:

output has any resulting handshake messages or key changes appended to it.